@@ -17,7 +17,7 @@ Usage::
     describe_subscribers_for_notification_paginator: DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_budgets.type_defs import (
     DescribeBudgetsResponseTypeDef,
@@ -37,33 +37,33 @@ __all__ = (
 
 class DescribeBudgetsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+    [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
     """
 
     def paginate(
         self, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeBudgetsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeBudgetsResponseTypeDef]:
         """
-        [DescribeBudgets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
+        [DescribeBudgets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
         """
 
 
 class DescribeNotificationsForBudgetPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+    [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
     """
 
     def paginate(
         self, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeNotificationsForBudgetResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeNotificationsForBudgetResponseTypeDef]:
         """
-        [DescribeNotificationsForBudget.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
+        [DescribeNotificationsForBudget.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
         """
 
 
 class DescribeSubscribersForNotificationPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+    [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
     """
 
     def paginate(
@@ -72,7 +72,7 @@ class DescribeSubscribersForNotificationPaginator(Boto3Paginator):
         BudgetName: str,
         Notification: NotificationTypeDef,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[DescribeSubscribersForNotificationResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeSubscribersForNotificationResponseTypeDef]:
         """
-        [DescribeSubscribersForNotification.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.11/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
+        [DescribeSubscribersForNotification.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
         """
